@@ -254,11 +254,11 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
             keep_engine_alive = True
 
         if new_engine:
-            self.__execute_sql(engine, spid, keep_engine_alive, query_str, execute, queue_cursor, csv_path,
+            return self.__execute_sql(engine, spid, keep_engine_alive, query_str, execute, queue_cursor, csv_path,
                                csv_replace, delimiter, quotechar, quoting)
         else:
             with self.__engine_lock:
-                self.__execute_sql(engine, spid, keep_engine_alive, query_str, execute, queue_cursor, csv_path,
+                return self.__execute_sql(engine, spid, keep_engine_alive, query_str, execute, queue_cursor, csv_path,
                                    csv_replace, delimiter, quotechar, quoting)
 
     def __execute_sql(self, engine, spid, keep_engine_alive, query_str, execute=False, queue_cursor=False,
